var exec = require('cordova/exec');
var channel = require('cordova/channel');

channel.createSticky('onCordovaInfoReady');
// Tell cordova channel to wait on the CordovaInfoReady event
channel.waitForInitialization('onCordovaInfoReady');

const SPEECH = 'Speech'
const API_LIST = {
    GET_SUPPORTED_LANGUAGES: "getSupportedLanguages",
    GET_DEFAULT_LANGUAGE: "getDefaultLanguage",
    SPEAK_OUT: "speakOut",
    INIT_RECOGNITION: "initRecognition",
    START_RECOGNITION: "startRecognition",
    STOP_RECOGNITION: "stopRecognition"
}

// exports.echo = function (arg0, success, error) {
//     exec(success, error, SPEECH, 'echo', [arg0]);
// };

// exports.echojs = function (arg0, success, error) {
//     if (arg0 && typeof arg0 == 'string' && arg0.length > 0) {
//         success(arg0)
//     } else {
//         error("Empty message!")
//     }
// }

function Speech() {
    this.supportedLanguages = null
    this.defaultLanguage = null

    var me = this

    channel.onCordovaReady.subscribe(function () {
        me[API_LIST.GET_SUPPORTED_LANGUAGES](supportedLanguages => {
            me.supportedLanguages = supportedLanguages
            me[API_LIST.GET_DEFAULT_LANGUAGE](defaultLanguage => {
                me.defaultLanguage = defaultLanguage
                channel.onCordovaInfoReady.fire();
            }, err => {
                console.error(err)
            })
        }, err => {
            console.error(err)
        })
    })
}

Speech.prototype[API_LIST.GET_SUPPORTED_LANGUAGES] = function (success, error) {
    exec(success, error, SPEECH, API_LIST.GET_SUPPORTED_LANGUAGES, [])
}

Speech.prototype[API_LIST.GET_DEFAULT_LANGUAGE] = function (success, error) {
    exec(success, error, SPEECH, API_LIST.GET_DEFAULT_LANGUAGE, [])
}

Speech.prototype[API_LIST.SPEAK_OUT] = function (message, success, error, options) {
    let pitchRate = options && options.pitchRate ? options.pitchRate : 0.0
    let speechRate = options && options.speechRate ? options.speechRate : 0.0
    exec(success, error, SPEECH, API_LIST.SPEAK_OUT, [message, pitchRate, speechRate])
}

Speech.prototype[API_LIST.INIT_RECOGNITION] = function (success, error, options) {
    let language = options && options.language ? options.language : ""
    exec(success, error, SPEECH, API_LIST.INIT_RECOGNITION, [language])
}

Speech.prototype[API_LIST.START_RECOGNITION] = function (success, error, options) {
    let partialResultRequired = options && options.partialResultRequired ? options.partialResultRequired : false
    let offlineRecognitionRequired = options && options.offlineRecognitionRequired ? options.offlineRecognitionRequired : false
    exec(success, error, SPEECH, API_LIST.START_RECOGNITION, [partialResultRequired, offlineRecognitionRequired])
}

Speech.prototype[API_LIST.STOP_RECOGNITION] = function (success, error) {
    exec(success, error, SPEECH, API_LIST.STOP_RECOGNITION, [])
}

module.exports = new Speech();
